@@ -1,18 +1,18 @@
 package Sah::Schema::simple_int_range;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-07-16'; # DATE
+our $DATE = '2021-07-17'; # DATE
 our $DIST = 'Sah-Schemas-IntRange'; # DIST
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 our $schema = [str => {
     summary => 'Simple integer range, e.g. 1-10 / -2-7',
     match => qr/\A(?:-?[0-9]+)\s*-\s*(?:-?[0-9]+)\z/,
     prefilters => ['IntRange::check_simple_int_range'],
     examples => [
-        {data=>'', valid=>0},
-        {data=>'1', valid=>0},
-        {data=>'-2', valid=>0},
+        {data=>'', valid=>0, summary=>'Empty string'},
+        {data=>'1', valid=>0, summary=>'Not a range but single positive integer'},
+        {data=>'-2', valid=>0, summary=>'Not a range but single negative integer'},
 
         {data=>'1-1', valid=>1},
         {data=>'1-2', valid=>1},
@@ -21,10 +21,10 @@ our $schema = [str => {
         {data=>'-1-2', valid=>1},
         {data=>'-10--1', valid=>1},
 
-        {data=>'1-', valid=>0},
+        {data=>'1-', valid=>0, summary=>'Missing end value'},
         {data=>'1-1.5', valid=>0, sumary=>'Float'},
         {data=>'9-2', valid=>0, summary=>'start value cannot be larger than end value'},
-        {data=>'1-2-3', valid=>0},
+        {data=>'1-2-3', valid=>0, summary=>'Invalid syntax'},
         {data=>' 1-2 ', valid=>0, summary=>'Leading and trailing whitespace is currently not allowed'},
     ],
 }, {}];
@@ -44,7 +44,7 @@ Sah::Schema::simple_int_range - Simple integer range, e.g. 1-10 / -2-7
 
 =head1 VERSION
 
-This document describes version 0.002 of Sah::Schema::simple_int_range (from Perl distribution Sah-Schemas-IntRange), released on 2021-07-16.
+This document describes version 0.003 of Sah::Schema::simple_int_range (from Perl distribution Sah-Schemas-IntRange), released on 2021-07-17.
 
 =head1 SYNOPSIS
 
@@ -109,11 +109,11 @@ L<Perinci::CmdLine> to create a CLI:
 
 Sample data:
 
- ""  # INVALID
+ ""  # INVALID (Empty string)
 
- 1  # INVALID
+ 1  # INVALID (Not a range but single positive integer)
 
- -2  # INVALID
+ -2  # INVALID (Not a range but single negative integer)
 
  "1-1"  # valid
 
@@ -127,13 +127,13 @@ Sample data:
 
  "-10--1"  # valid
 
- "1-"  # INVALID
+ "1-"  # INVALID (Missing end value)
 
  "1-1.5"  # INVALID
 
  "9-2"  # INVALID (start value cannot be larger than end value)
 
- "1-2-3"  # INVALID
+ "1-2-3"  # INVALID (Invalid syntax)
 
  " 1-2 "  # INVALID (Leading and trailing whitespace is currently not allowed)
 
