@@ -1,21 +1,21 @@
 package Sah::Schema::simple_int_seq;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-07-16'; # DATE
+our $DATE = '2021-07-17'; # DATE
 our $DIST = 'Sah-Schemas-IntRange'; # DIST
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 our $schema = [str => {
-    summary => 'Simple integer sequence, e.g. 1,3,12',
+    summary => 'Simple integer sequence, e.g. 1,-3,12',
     match => qr/\A(?:-?[0-9]+)(?:\s*,\s*(?:-?[0-9]+))*\z/,
     #prefilters => ['IntRange::check_simple_int_seq'],
     description => <<'_',
 
-TODO: infinite sequence, e.g. '1,2,3,...'.
+TODO: infinite sequence, e.g. '1,-2,3,-4,...'.
 
 _
     examples => [
-        {data=>'', valid=>0},
+        {data=>'', valid=>0, summary=>'Empty string'},
         {data=>'1-2', valid=>0, summary=>'A range m-n is not valid in simple integer sequence'},
         {data=>'1,', valid=>0, summary=>'Dangling comma is currently not allowed'},
         {data=>'1,,2', valid=>0, summary=>'Multiple commas are currently not allowed'},
@@ -29,7 +29,7 @@ _
 }, {}];
 
 1;
-# ABSTRACT: Simple integer sequence, e.g. 1,3,12
+# ABSTRACT: Simple integer sequence, e.g. 1,-3,12
 
 __END__
 
@@ -39,11 +39,11 @@ __END__
 
 =head1 NAME
 
-Sah::Schema::simple_int_seq - Simple integer sequence, e.g. 1,3,12
+Sah::Schema::simple_int_seq - Simple integer sequence, e.g. 1,-3,12
 
 =head1 VERSION
 
-This document describes version 0.002 of Sah::Schema::simple_int_seq (from Perl distribution Sah-Schemas-IntRange), released on 2021-07-16.
+This document describes version 0.003 of Sah::Schema::simple_int_seq (from Perl distribution Sah-Schemas-IntRange), released on 2021-07-17.
 
 =head1 SYNOPSIS
 
@@ -108,7 +108,7 @@ L<Perinci::CmdLine> to create a CLI:
 
 Sample data:
 
- ""  # INVALID
+ ""  # INVALID (Empty string)
 
  "1-2"  # INVALID (A range m-n is not valid in simple integer sequence)
 
@@ -128,7 +128,7 @@ Sample data:
 
 =head1 DESCRIPTION
 
-TODO: infinite sequence, e.g. '1,2,3,...'.
+TODO: infinite sequence, e.g. '1,-2,3,-4,...'.
 
 =head1 HOMEPAGE
 
