@@ -1,9 +1,9 @@
 package Sah::Schema::simple_uint_seq;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-07-16'; # DATE
+our $DATE = '2021-07-17'; # DATE
 our $DIST = 'Sah-Schemas-IntRange'; # DIST
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 our $schema = [str => {
     summary => 'Simple unsigned integer sequence, e.g. 1,3,12',
@@ -15,7 +15,7 @@ TODO: infinite sequence, e.g. '1,2,3,...'.
 
 _
     examples => [
-        {data=>'', valid=>0},
+        {data=>'', valid=>0, summary=>'Empty string'},
         {data=>'1-2', valid=>0, summary=>'A range m-n is not valid in simple integer sequence'},
         {data=>'1,', valid=>0, summary=>'Dangling comma is currently not allowed'},
         {data=>'1,,2', valid=>0, summary=>'Multiple commas are currently not allowed'},
@@ -45,7 +45,7 @@ Sah::Schema::simple_uint_seq - Simple unsigned integer sequence, e.g. 1,3,12
 
 =head1 VERSION
 
-This document describes version 0.002 of Sah::Schema::simple_uint_seq (from Perl distribution Sah-Schemas-IntRange), released on 2021-07-16.
+This document describes version 0.003 of Sah::Schema::simple_uint_seq (from Perl distribution Sah-Schemas-IntRange), released on 2021-07-17.
 
 =head1 SYNOPSIS
 
@@ -110,7 +110,7 @@ L<Perinci::CmdLine> to create a CLI:
 
 Sample data:
 
- ""  # INVALID
+ ""  # INVALID (Empty string)
 
  "1-2"  # INVALID (A range m-n is not valid in simple integer sequence)
 
