@@ -1,9 +1,9 @@
 package Sah::Schema::uint_range;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-07-16'; # DATE
+our $DATE = '2021-07-17'; # DATE
 our $DIST = 'Sah-Schemas-IntRange'; # DIST
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 our $schema = [str => {
     summary => 'Unsigned integer range (sequence of uints/simple ranges), e.g. 1 / 5-7 / 1,10 / 1,5-7,10',
@@ -15,15 +15,18 @@ our $schema = [str => {
                 )*\z/x,
     prefilters => ['IntRange::check_uint_range'],
     examples => [
-        {data=>'', valid=>0},
+        {data=>'', valid=>0, summary=>'Empty string'},
 
         # single int
+
         {data=>'1', valid=>1},
         {data=>'-2', valid=>0,
          summary=>'Negative'},
+
         {data=>'1.5', valid=>0, summary=>'Float'},
 
         # simple int range
+
         {data=>'1-1', valid=>1},
         {data=>'1-2', valid=>1},
         {data=>'1 - 2', valid=>1},
@@ -32,6 +35,7 @@ our $schema = [str => {
          summary=>"Negative"},
         {data=>'-10--1', valid=>0,
          summary=>"Negative"},
+
         {data=>'1-', valid=>0, summary=>'Missing end value'},
         {data=>'1-1.5', valid=>0, sumary=>'Float'},
         {data=>'9-2', valid=>0, summary=>'start value cannot be larger than end value'},
@@ -39,18 +43,22 @@ our $schema = [str => {
         {data=>' 1-2 ', valid=>0, summary=>'Leading and trailing whitespace is currently not allowed'},
 
         # simple int seq
+
         {data=>'1,2', valid=>1},
         {data=>'1 , 2', valid=>1},
         {data=>'1,2,-3,4', valid=>0,
          summary=>"Negative"},
+
         {data=>'1,2,-3,4.5', valid=>0, summary=>'Float'},
         {data=>'1,', valid=>0, summary=>'Dangling comma is currently not allowed'},
         {data=>'1,,2', valid=>0, summary=>'Multiple commas are currently not allowed'},
 
         # seq of ints/simple int ranges
+
         {data=>'1,2-5', valid=>1},
         {data=>'-1,-2-5,7,9-9', valid=>0,
          summary=>"Negative"},
+
         {data=>'1,9-2', valid=>0, summary=>'start value cannot be larger than end value'},
 
     ],
@@ -71,7 +79,7 @@ Sah::Schema::uint_range - Unsigned integer range (sequence of uints/simple range
 
 =head1 VERSION
 
-This document describes version 0.002 of Sah::Schema::uint_range (from Perl distribution Sah-Schemas-IntRange), released on 2021-07-16.
+This document describes version 0.003 of Sah::Schema::uint_range (from Perl distribution Sah-Schemas-IntRange), released on 2021-07-17.
 
 =head1 SYNOPSIS
 
@@ -136,7 +144,7 @@ L<Perinci::CmdLine> to create a CLI:
 
 Sample data:
 
- ""  # INVALID
+ ""  # INVALID (Empty string)
 
  1  # valid
 
